@@ -118,6 +118,7 @@ struct _EvView {
 	/* Find */
 	EvJobFind *find_job;
 	GList **find_pages; /* Backwards compatibility */
+	gint find_page;
 	gint find_result;
 	gboolean jump_to_find_result;
 	gboolean highlight_find_results;
@@ -199,10 +200,13 @@ struct _EvView {
 	/* Annotations */
 	GList             *window_children;
 	EvViewWindowChild *window_child_focus;
-	EvMapping         *focus_annotation;
 	gboolean           adding_annot;
 	EvAnnotationType   adding_annot_type;
 
+	/* Focus */
+	EvMapping *focused_element;
+	guint focused_element_page;
+
 	/* Synctex */
 	EvMapping *synctex_result;
 
@@ -241,6 +245,7 @@ struct _EvViewClass {
 				       GtkMovementStep step,
 				       gint            count,
 				       gboolean        extend_selection);
+	void     (*activate)          (EvView         *view);
 };
 
 void _get_page_size_for_scale_and_rotation (EvDocument *document,
